@@ -7,7 +7,7 @@ use Alien::Base::ModuleBuild::File;
 use Alien::Base::ModuleBuild::Utils qw/pattern_has_capture_groups/;
 
 # ABSTRACT: Private class
-our $VERSION = '1.12'; # VERSION
+our $VERSION = '1.17'; # VERSION
 
 sub new {
   my $class = shift;
@@ -18,8 +18,11 @@ sub new {
   $obj->{c_compiler_required} = 1
     unless defined $obj->{c_compiler_required};
 
-  if($obj->{exact_filename} && $obj->{location} !~ m{/$}) {
-    $obj->{location} .= '/'
+  my $location = $obj->{location};
+  $location = '' unless defined $location;
+
+  if(defined $obj->{exact_filename} && $location !~ m{/$}) {
+    $obj->{location} = $location . '/'
   }
 
   return $obj;
@@ -39,9 +42,65 @@ sub location {
   return $self->{location};
 }
 
+sub is_network_fetch {
+  die "must override in the subclass";
+}
+
+sub is_secure_fetch {
+  die "must override in the subclass";
+}
+
+sub has_digest
+{
+  my($self) = @_;
+  defined $self->{exact_filename} && $self->{exact_version} && (defined $self->{sha1} || defined $self->{sha256});
+}
+
 sub probe {
   my $self = shift;
 
+  require Alien::Base::ModuleBuild;
+  if(!Alien::Base::ModuleBuild->alien_install_network && $self->is_network_fetch) {
+    die "network fetch is disabled via ALIEN_INSTALL_NETWORK";
+  }
+
+  my $rule = Alien::Base::ModuleBuild->alien_download_rule;
+  if($rule eq 'warn') {
+
+    unless($self->is_secure_fetch || $self->has_digest) {
+      warn "!!! NOTICE OF FUTURE CHANGE IN BEHAVIOR !!!\n";
+      warn "A future version of Alien::Base::ModuleBuild will die here by default with this exception: File fetch is insecure and has no digest.  Required by ALIEN_DOWNLOAD_RULE=digest_or_encrypt.";
+      warn "!!! NOTICE OF FUTURE CHANGE IN BEHAVIOR !!!\n";
+    }
+
+  } elsif($rule eq 'digest') {
+
+    unless($self->has_digest) {
+      die "File fetch has no digest.  Required by ALIEN_DOWNLOAD_RULE=digest.";
+    }
+
+  } elsif($rule eq 'encrypt') {
+
+    unless($self->is_secure_fetch) {
+      die "File fetch is insecure.  Secure fetch required by ALIEN_DOWNLOAD_RULE=encrypt.";
+    }
+
+  } elsif($rule eq 'digest_or_encrypt') {
+
+    unless($self->is_secure_fetch || $self->has_digest) {
+      die "File fetch is insecure and has no digest.  Required by ALIEN_DOWNLOAD_RULE=digest_or_encrypt.";
+    }
+
+  } elsif($rule eq 'digest_and_encrypt') {
+
+    unless($self->is_secure_fetch && $self->has_digest) {
+      die "File fetch is insecure and has no digest.  Both are required by ALIEN_DOWNLOAD_RULE=digest_and_encrypt.";
+    }
+
+  } else {
+    die 'internal error';
+  }
+
   my $pattern = $self->{pattern};
 
   my @files;
@@ -50,7 +109,7 @@ sub probe {
     # if filename provided, use that specific file
     @files = ($self->{exact_filename});
   } else {
-    @files = $self->list_files();
+    @files = $self->list_files;
 
     if ($pattern) {
       @files = grep { $_ =~ $pattern } @files;
@@ -104,7 +163,17 @@ Alien::Base::ModuleBuild::Repository - Private class
 
 =head1 VERSION
 
-version 1.12
+version 1.17
+
+=head1 SEE ALSO
+
+=over 4
+
+=item L<Alien>
+
+=item L<Alien::Base>
+
+=back
 
 =head1 AUTHOR
 
@@ -142,13 +211,13 @@ Kang-min Liu (劉康民, gugod)
 
 Nicholas Shipp (nshp)
 
-Petr Pisar (ppisar)
+Petr Písař (ppisar)
 
 Alberto Simões (ambs)
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012-2020 by Joel A Berger.
+This software is copyright (c) 2012-2022 by Joel A Berger.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
